@@ -1,3 +1,3 @@
 from transformers import AutoModelForSequenceClassification, AutoTokenizer
 from .training import load_model
-from .datasets import load_datasets
+from .datasets import load_datasets, id2label, label2id
